function [] = Dynamics()
% Dynamics.m
%
% kinematics and dynamics
%
% Revision history
% 211201 Drafted
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
global x_ dx_
global t_
global m1 m2 r1 r2 I1 I2 c1 c2 g trq_max
global SW_LNR_DYN ANG_delta B_goal
global N_alp N_psi N_dalp N_dpsi N_trq_cmd N_trq_apl N_p0 N_p1 N_p2
global cntrl

%%% constants

a	= (m1+m2)*r1^2 + I1;
b	= m2*r1*r2;
c	= m2*r2^2 + I2;
d	= m2*g*r2;
e	= (m1+m2)*g*r1;

delta	= ANG_delta;

%%% kinematics
psi			= x_(N_psi);
alp			= x_(N_alp);
dpsi		= x_(N_dpsi);
dalp		= x_(N_dalp);

%%% translational motion
p0			= r1*psi*[cos(delta);sin(delta)];
p1			= p0 + r1*[-sin(delta);cos(delta)];
p2			= p1 + r2*[sin(alp);cos(alp)];
v1			= r1*dpsi*[cos(delta);sin(delta)];
v2			= v1 + r2*dalp*[cos(alp);-sin(alp)];

%%% linear dynamics
A		= [a, b;b, c];
B		= [1; -1];
F1		= [0, 0;0, d];
F2		= [-c1, 0;0, -c2];
matA	= [zeros(2,2), eye(2,2);inv(A)*F1, inv(A)*F2];
matB	= [zeros(2,1);inv(A)*B];

%%% user defined controller
u_cmd	= Control(t_,psi,alp,dpsi,dalp,B_goal);
u_apl	= max(min(u_cmd, trq_max),-trq_max);

x_(N_trq_cmd)	= u_cmd;
x_(N_trq_apl)	= u_apl;
x_(N_p0)		= p0;
x_(N_p1)		= p1;
x_(N_p2)		= p2;
%%%
dx_(N_alp)	= dalp;
dx_(N_psi)	= dpsi;
if ( SW_LNR_DYN ),	% linear dynamics
	dx_([N_dpsi,N_dalp])	= matA(3:4,1:4)*x + matB(3:4,1)*u_apl;
else				% nonlinear dynamics
	A_		= [a, b*cos(alp+delta);b*cos(alp+delta), c];
	dx_([N_dpsi,N_dalp])	= inv(A_)*[b*sin(alp+delta)*dalp^2-c1*dpsi-e*sin(delta)+u_apl;...
									   d*sin(alp)-c2*dalp-u_apl];
end
%%%
