function [] = set_Constants
% set_Constants.m
%
% Parameter Setting
%
% Revision history
% 211201 Drafted
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
global dth_ smt_ nde_ nsv_ ndisp
global m1 m2 r1 r2 I1 I2 c1 c2 g trq_max
global N_alp N_psi N_dalp N_dpsi N_trq_cmd N_trq_apl N_p0 N_p1 N_p2
global N_stay N_penalty
global ANG_delta B_goal
global user
%%% Simulation environment parameters
dth_		= 0.02;		% step width of numerical integration [s]
smt_ 		= 20;		% total simulation time [s]
nde_		= 4;		% number of state variables
nsv_		= 14;		% number of saved variabels
ndisp		= 2;		% graph display frequency (if ndisp=2, then once in two intervals)
%%% Simulation setting
g			= 9.81/6;	% the gravity constant on the moon surface [m/s2]*
ANG_delta	= 0.00;		% anlge of the slope [rad]*
dB			= 1.5;		% distance of the area B from point A [m]*
wB			= 0.10;		% half width of area B [m]*
t_s_min		= 5;		% minimum stay time within area B [s]*
B_goal		= [dB, wB, t_s_min];
						% goal state of area B
%%% "Moon Cycler" property
I1			= 0.4e-1;	% the wheel inertia [kgm2]
I2			= 0.2e-2;	% the saddle inertia [kgm2]
m1			= 2.0;		% the wheel mass [kg]*
m2			= 2.0;		% the saddle mass [kg]*
r1			= 0.5;		% the wheel radius [m]*
r2			= 0.4;		% the rod length [m]*
c1			= 0.3;		% the wheel viscous friction coefficient [Nms]*
c2			= 0.1;		% the link viscous friction coefficient [Nms]*
trq_max		= m2*r2*g*2;
%%% Note. The value that has asterisk(*) may be changed at the contest site to excite the game.

%%% constant to be transfered to the user via global varialbe "user"
%%% environment property
user.g		= g;
user.delta	= ANG_delta;

%%% "Moon Cycler" property
user.m1		= m1;
user.m2		= m2;
user.r1		= r1;
user.r2		= r2;
user.I1		= I1;
user.I2		= I2;
user.c1		= c1;
user.c2		= c2;

%%% index to the saved variables
N_psi		=  1: 1;	% wheel angle (1x1)
N_alp		=  2: 2;	% saddle angle (1x1)
N_dpsi		=  3: 3;	% wheel angular velocity (1x1)
N_dalp		=  4: 4;	% saddle angular velocity (1x1)
N_trq_cmd	=  5;		% commanded wheel torque (1x1)
N_trq_apl	=  6;		% applied wheel torque (1x1)
N_p0		=  7: 8;	% contact position of the wheel (2x1)
N_p1		=  9:10;	% wheel position (2x1)
N_p2		= 11:12;	% saddle position (2x1)
N_stay		= 13;		% continuous stay time within region B (1x1)
N_penalty	= 14;		% penalty time (1x1)
%%%
%%%
