function u = Control(t,psi,alp,dpsi,dalp,B_goal)
% Control.m
%
% user-defined control algorithm
%
% INPUT
%	t		: current time [s]
%	psi		: wheel angle [rad]
%	alp		: saddle angle [rad]
%	dpsi	: wheel angular velocity [rad/s]
%	dalp	: saddle angular velocity [rad/s]
%	B_goal	: goal position, range, and stay time [m],[m], [s]
% OUTPUT
%	u		: commanded wheel torque [Nm]
%
% Revision history
% 211201 Drafted
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
% Please design your OWN control algorithm.
% Here is an example.
%
% Please DO NOT use toolbox functions.
% Please define YOUR functions in the "user" folder.
%
% user can use global variable under the name of user
global user

%%% environment property
g		= user.g;
delta	= user.delta;

%%% "Moon Cycler" property
m1		= user.m1;
m2		= user.m2;
r1		= user.r1;
r2		= user.r2;
I1		= user.I1;
I2		= user.I2;
c1		= user.c1;
c2		= user.c2;

%%%

a		= (m1+m2)*r1^2 + I1;
b		= m2*r1*r2;
c		= m2*r2^2 + I2;
d		= m2*g*r2;
e		= (m1+m2)*g*r1;

%%% kinematics
%%% translational motion
p0		= r1*psi*[cos(delta);sin(delta)];
p1		= p0 + r1*[-sin(delta);cos(delta)];
p2		= p1 + r2*[sin(alp);cos(alp)];
v1		= r1*dpsi*[cos(delta);sin(delta)];
v2		= v1 + r2*dalp*[cos(alp);-sin(alp)];

%%% target state from the goal point B
psi_goal	= B_goal(1)/r1;

%%% linear dynamics
A		= [a, b;b, c];
B		= [1; -1];
F1		= [0, 0;0, d];
F2		= [-c1, 0;0, -c2];
matA	= [zeros(2,2), eye(2,2);inv(A)*F1, inv(A)*F2];
matB	= [zeros(2,1);inv(A)*B];

A		= [a, b*cos(alp+delta);b*cos(alp+delta), c];
B		= [1; -1];
if ( cos(alp)>0 ),	% when the saddle is up
	F1		= [0, 0;0, d];
else				% when the saddle is not up
	F1		= [0, 0;0,-d];
end
F2		= [-c1, 0;0, -c2];
matA	= [zeros(2,2), eye(2,2);inv(A)*F1, inv(A)*F2];
matB	= [zeros(2,1);inv(A)*B];

if ( t==0 ),
	user.alp	= 0;
end

%%% LQ controller
Q		= diag([1/0.02^2,1/0.05^2,1/0.01^2,1/0.01^2]);
R		= 1/0.1^2;
K		= my_lqr(matA,matB,Q,R);

alp			= mod(alp,2*pi);
x			= [psi;alp;dpsi;dalp];
if ( abs(norm(p0)-B_goal(1))<B_goal(2)*0.1 ),
	user.alp	= pi;
end
x0			= [psi_goal;user.alp;0;0];
u			= -K*(x-x0);
