function [K,S,E] = my_lqr(A,B,Q,R)
% my_lqr.m
%
% user-defined linear quadratic controller (Arimoto-Potter method)
%
% INPUT
%	A		: system matrix
%	B		: input matrix
%	Q		: weight matrix (control error)
%	R		: weight matrix (control input)
% OUTPUT
%	K		: controller gain matrix
%	S		: solution of algebraic Ricatti equation
%	E		: eigenvalues of the closed loop system
%
% Revision history
% 211215 Drafted
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
H			= [ A, -B*inv(R)*B';
			   -Q, -A'];
[V,Lamda]	= eig(H);
n			= size(A,1);
num			= 0;
for i = 1:n*2,
	if real(Lamda(i,i) < 0),
		num		= num + 1;
		V1(1:n,num)	= V(  1:  n,i);
		V2(1:n,num)	= V(n+1:2*n,i);
	end
end
S			= real(V2*inv(V1));
K			= inv(R)*B'*S;
E			= eig(A-B*K);
